{#
    Copyright (C) 2020-2021 CERN.
    Copyright (C) 2020 Northwestern University.
    Copyright (C) 2021 New York University.

    Invenio RDM Records is free software; you can redistribute it and/or modify
    it under the terms of the MIT License; see LICENSE file for more details.
#}

<div id="recordCitation" data-record='{{ record | tojson }}'
  data-styles='{{ config.get("RDM_CITATION_STYLES") | tojson }}'
  data-defaultstyle='{{ config.get("RDM_CITATION_STYLES_DEFAULT") | tojson }}'>
</div>
