{# -*- coding: utf-8 -*-

  This file is part of Invenio.
  Copyright (C) 2022 CERN.

  Invenio is free software; you can redistribute it and/or modify it
  under the terms of the MIT License; see LICENSE file for more details.
#}
{% set title = request.title %}
{% extends "invenio_requests/details/index.html" %}

{% set active_community_header_menu_item = 'members' %}
{% set active_members_menu_item = 'invitations' %}

{% block request_header_title %}
  {{ request.title }}
{% endblock request_header_title %}

{% block settings_body %}
  <div class="sixteen wide mobile sixteen wide tablet thirteen wide computer column right floated">
    {% block request_body %}
      {{ super() }}
    {% endblock request_body %}
  </div>
{% endblock %}

{% block page_body %}
{{ super.super() }}
{% endblock page_body %}
