{# -*- coding: utf-8 -*-

  This file is part of Invenio.
  Copyright (C) 2016-2020 CERN.

  Invenio is free software; you can redistribute it and/or modify it
  under the terms of the MIT License; see LICENSE file for more details.
#}

{% extends "invenio_communities/details/base.html" %}

{%- set title = _("Search ") + community.metadata.title -%}

{%- block javascript %}
    {{ super() }}
    {{ webpack['invenio-communities-details-search.js'] }}
{%- endblock %}

{%- block page_body %}
{{ super() }}
<div data-invenio-search-config='{{
  search_app_communities_records_config(app_id="rdm-search",
  endpoint=endpoint) | tojson }}'></div>
{%- endblock page_body %}
