{#

  Copyright (C) 2019-2020 CERN.
  Copyright (C) 2019-2020 Northwestern University.
  Copyright (C)      2021 Graz University of Technology.

  Invenio App RDM is free software; you can redistribute it and/or modify it
  under the terms of the MIT License; see LICENSE file for more details.
#}

<footer id="rdm-footer-element">
  {%- block footer_top %}
    <div class="footer-top">
      <div class="ui container">
        {%- block footer_top_left %}
          <div class="ui grid">
            <div class="rdm-footer five wide tablet two wide computer column">
              <h2 class="ui small header">{{_("About InvenioRDM")}}</h2>
              {% trans invenio_rdm="http://inveniosoftware.org/products/rdm" %}
              <p><a href="{{invenio_rdm}}">Product page</a></p>
              {% endtrans %}
              {% trans invenio_rdm_features="https://inveniosoftware.org/products/rdm/#features" %}
              <p><a href="{{invenio_rdm_features}}">Features</a></p>
              {% endtrans %}
              {% trans invenio_rdm_roadmap="https://inveniosoftware.org/products/rdm/roadmap/" %}
              <p><a href="{{invenio_rdm_roadmap}}">Roadmap</a></p>
              {% endtrans %}
              {% trans invenio_rdm_demo_site="http://inveniordm.web.cern.ch" %}
              <p><a href="{{invenio_rdm_demo_site}}">Demo site</a></p>
              {% endtrans %}
            </div>
            <div class="rdm-footer five wide tablet two wide computer column">
              <h2 class="ui small header">{{_ ("Get involved")}}</h2>
              {% trans invenio_rdm_gh="https://github.com/inveniosoftware/invenio-app-rdm" %}
              <p><a href="{{invenio_rdm_gh}}">GitHub</a></p>
              {% endtrans %}
              {% trans invenio_rdm_milestones="https://github.com/inveniosoftware/product-rdm" %}
              <p><a href="{{invenio_rdm_milestones}}">Project Milestones</a></p>
              {% endtrans %}
              {% trans invenio_rdm_docs_site="http://inveniordm.docs.cern.ch" %}
              <p><a href="{{invenio_rdm_docs_site}}">Documentation</a></p>
              {% endtrans %}
            </div>
            <div class="rdm-footer five wide tablet two wide computer column">
              <h2 class="ui small header">{{_ ("Community")}}</h2>
              {% trans invenio_rdm_chatroom="https://discord.gg/8qatqBC" %}
              <p><a href="{{invenio_rdm_chatroom}}">Chatroom</a></p>
              {% endtrans %}
              {% trans invenio_rdm_talk="https://invenio-talk.web.cern.ch/c/projects/invenio-rdm" %}
              <p><a href="{{invenio_rdm_talk}}">Forum</a></p>
              {% endtrans %}
              {% trans invenio_events="https://inveniosoftware.org/events/" %}
              <p><a href="{{invenio_events}}">Events & training</a></p>
              {% endtrans %}
            </div>

          {%- endblock footer_top_left %}
          <div class="six wide column right aligned">
            {%- block footer_top_right %}
            {%- endblock footer_top_right %}
          </div>
        </div>
      </div>
    </div>
    {%- endblock footer_top %}
    {%- block footer_bottom %}
    <div class="footer-bottom sub-footer">
      <div class="ui container">
        <div class="ui grid">
          <div class="eight wide column left middle aligned">
            {%- block footer_bottom_left %}
            {% trans invenio_rdm="http://inveniosoftware.org/products/rdm" %}Powered by <a
              href="{{invenio_rdm}}">InvenioRDM</a>{% endtrans %}
            {%- endblock footer_bottom_left %}
          </div>
          <div class="eight wide column right aligned">
            {%- block footer_bottom_right %}
            {%- if config.I18N_LANGUAGES %}
            {% from "invenio_i18n/macros/language_selector.html" import language_selector_dropdown %}
            {{ language_selector_dropdown() }}
            {%- endif %}
            {%- endblock footer_bottom_right %}
          </div>
        </div>
      </div>
    </div>
    {%- endblock footer_bottom %}
</footer>
